searchData={"items":[{"type":"module","title":"ExGtin","doc":"Documentation for ExGtin. This library provides\nfunctionality for validating GTIN compliant codes.","ref":"ExGtin.html"},{"type":"function","title":"ExGtin.generate/1","doc":"Generates valid  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nReturns code with check digit","ref":"ExGtin.html#generate/1"},{"type":"function","title":"Examples - ExGtin.generate/1","doc":"iex> ExGtin.generate(\"629104150021\")\n    {:ok, \"6291041500213\"}\n\n    iex> ExGtin.generate(\"62921\")\n    {:error, \"Invalid GTIN Code Length\"}","ref":"ExGtin.html#generate/1-examples"},{"type":"function","title":"ExGtin.generate!/1","doc":"Generates valid  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nThrows Argument Exception if there was an error","ref":"ExGtin.html#generate!/1"},{"type":"function","title":"Examples - ExGtin.generate!/1","doc":"iex> ExGtin.generate!(\"629104150021\")\n    \"6291041500213\"\n\n    iex> ExGtin.generate!(\"62921\")\n    ** (ArgumentError) Invalid GTIN Code Length","ref":"ExGtin.html#generate!/1-examples"},{"type":"function","title":"ExGtin.gs1_prefix_country/1","doc":"Find the GS1 prefix country for a GTIN number\n\nReturns `{atom, String.t()}`","ref":"ExGtin.html#gs1_prefix_country/1"},{"type":"function","title":"Examples - ExGtin.gs1_prefix_country/1","doc":"iex> ExGtin.gs1_prefix_country(\"53523235\")\n    {:ok, \"GS1 Malta\"}\n\n    iex> ExGtin.gs1_prefix_country(\"6291041500214\")\n    {:ok, \"GS1 Emirates\"}\n\n    iex> ExGtin.gs1_prefix_country(\"9541041500214\")\n    {:error, \"No GS1 prefix found\"}","ref":"ExGtin.html#gs1_prefix_country/1-examples"},{"type":"function","title":"ExGtin.normalize/1","doc":"Converts a GTIN or ISBN to GTIN-14 format","ref":"ExGtin.html#normalize/1"},{"type":"function","title":"Examples - ExGtin.normalize/1","doc":"iex> ExGtin.normalize(\"6291041500213\")\n    {:ok, \"16291041500210\"}","ref":"ExGtin.html#normalize/1-examples"},{"type":"type","title":"ExGtin.result/0","doc":"","ref":"ExGtin.html#t:result/0"},{"type":"function","title":"ExGtin.validate/1","doc":"Check for valid  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nReturns `{:ok, \"GTIN-#\"}` or `{:error}`","ref":"ExGtin.html#validate/1"},{"type":"function","title":"Examples - ExGtin.validate/1","doc":"iex> ExGtin.validate(\"6291041500213\")\n    {:ok, \"GTIN-13\"}\n\n    iex> ExGtin.validate(\"6291041500214\")\n    {:error, \"Invalid Code\"}","ref":"ExGtin.html#validate/1-examples"},{"type":"function","title":"ExGtin.validate!/1","doc":"Check for valid  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nThrows ArgumentError if an error occurs","ref":"ExGtin.html#validate!/1"},{"type":"function","title":"Examples - ExGtin.validate!/1","doc":"iex> ExGtin.validate!(\"6291041500213\")\n    \"GTIN-13\"","ref":"ExGtin.html#validate!/1-examples"},{"type":"module","title":"ExGtin.Validation","doc":"Documentation for ExGtin. This library provides\nfunctionality for validating GTIN compliant codes.","ref":"ExGtin.Validation.html"},{"type":"function","title":"ExGtin.Validation.check_code_length/1","doc":"Checks the code for the proper length as specified by the\nGTIN-8,12,13,14 specification\n\nReturns {atom, String.t()}","ref":"ExGtin.Validation.html#check_code_length/1"},{"type":"function","title":"Examples - ExGtin.Validation.check_code_length/1","doc":"iex> ExGtin.Validation.check_code_length([1,2,3,4,5,6,7,8])\n    {:ok, \"GTIN-8\"}\n\n    iex> ExGtin.Validation.check_code_length([1,2,3,4,5,6,7])\n    {:error, \"Invalid GTIN Code Length\"}","ref":"ExGtin.Validation.html#check_code_length/1-examples"},{"type":"function","title":"ExGtin.Validation.find_gs1_prefix_country/1","doc":"Find the GS1 prefix country for a GTIN number\n\nReturns `{atom, String.t()}`","ref":"ExGtin.Validation.html#find_gs1_prefix_country/1"},{"type":"function","title":"Examples - ExGtin.Validation.find_gs1_prefix_country/1","doc":"iex> ExGtin.Validation.find_gs1_prefix_country(\"53523235\")\n    {:ok, \"GS1 Malta\"}\n\n    iex> ExGtin.Validation.find_gs1_prefix_country(\"6291041500214\")\n    {:ok, \"GS1 Emirates\"}\n\n    iex> ExGtin.Validation.find_gs1_prefix_country(\"9541041500214\")\n    {:error, \"No GS1 prefix found\"}","ref":"ExGtin.Validation.html#find_gs1_prefix_country/1-examples"},{"type":"function","title":"ExGtin.Validation.generate_check_code_length/1","doc":"When generating the code, checks the code for\nthe proper length as specified by the GTIN-8,12,13,14 specification.\nThe code should be -1 the length of the GTIN code as the check digit\nwill be added later\n\nReturns {atom, String.t()}","ref":"ExGtin.Validation.html#generate_check_code_length/1"},{"type":"function","title":"Examples - ExGtin.Validation.generate_check_code_length/1","doc":"iex> ExGtin.Validation.generate_check_code_length([1,2,3,4,5,6,7])\n    {:ok, \"GTIN-8\"}\n\n    iex> ExGtin.Validation.generate_check_code_length([1,2,3,4,5,6])\n    {:error, \"Invalid GTIN Code Length\"}","ref":"ExGtin.Validation.html#generate_check_code_length/1-examples"},{"type":"function","title":"ExGtin.Validation.generate_check_digit/1","doc":"Generate check digit  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nReturns `number`","ref":"ExGtin.Validation.html#generate_check_digit/1"},{"type":"function","title":"Examples - ExGtin.Validation.generate_check_digit/1","doc":"iex> ExGtin.Validation.generate_check_digit([6,2,9,1,0,4,1,5,0,0,2,1])\n    3","ref":"ExGtin.Validation.html#generate_check_digit/1-examples"},{"type":"function","title":"ExGtin.Validation.generate_gtin_code/1","doc":"Generate valid  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nReturns `{atom, String.t()}`","ref":"ExGtin.Validation.html#generate_gtin_code/1"},{"type":"function","title":"Examples - ExGtin.Validation.generate_gtin_code/1","doc":"iex> ExGtin.Validation.generate_gtin_code(\"629104150021\")\n    {:ok, \"6291041500213\"}\n\n    iex> ExGtin.Validation.generate_gtin_code(\"62921\")\n    {:error, \"Invalid GTIN Code Length\"}","ref":"ExGtin.Validation.html#generate_gtin_code/1-examples"},{"type":"function","title":"ExGtin.Validation.gtin_check_digit/1","doc":"Check for valid  GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codes\n\nReturns `{atom, String.t()}`","ref":"ExGtin.Validation.html#gtin_check_digit/1"},{"type":"function","title":"Examples - ExGtin.Validation.gtin_check_digit/1","doc":"iex> ExGtin.Validation.gtin_check_digit(\"6291041500213\")\n    {:ok, \"GTIN-13\"}\n\n    iex> ExGtin.Validation.gtin_check_digit(\"6291041500214\")\n    {:error, \"Invalid Code\"}","ref":"ExGtin.Validation.html#gtin_check_digit/1-examples"},{"type":"function","title":"ExGtin.Validation.lookup_gs1_prefix/1","doc":"Looks up the GS1 prefix in a table\nGS1 Reference https://www.gs1.org/company-prefix\n\nReturns {atom, String.t()}","ref":"ExGtin.Validation.html#lookup_gs1_prefix/1"},{"type":"function","title":"ExGtin.Validation.mult_by_index_code/1","doc":"By index, returns the corresponding value to multiply\nthe digit by\n\nReturns `number`","ref":"ExGtin.Validation.html#mult_by_index_code/1"},{"type":"function","title":"Examples - ExGtin.Validation.mult_by_index_code/1","doc":"iex> ExGtin.Validation.mult_by_index_code(1)\n    1\n\n    iex> ExGtin.Validation.mult_by_index_code(2)\n    3","ref":"ExGtin.Validation.html#mult_by_index_code/1-examples"},{"type":"function","title":"ExGtin.Validation.multiply_and_sum_array/1","doc":"Calculates the sum of the digits in a string and multiplied value based on index order\n\nReturns `number`","ref":"ExGtin.Validation.html#multiply_and_sum_array/1"},{"type":"function","title":"Examples - ExGtin.Validation.multiply_and_sum_array/1","doc":"iex> ExGtin.Validation.multiply_and_sum_array([6,2,9,1,0,4,1,5,0,0,2,1])\n    57","ref":"ExGtin.Validation.html#multiply_and_sum_array/1-examples"},{"type":"function","title":"ExGtin.Validation.subtract_from_nearest_multiple_of_ten/1","doc":"Calculates the difference of the highest rounded multiple of 10\n\nReturns `number`","ref":"ExGtin.Validation.html#subtract_from_nearest_multiple_of_ten/1"},{"type":"function","title":"Examples - ExGtin.Validation.subtract_from_nearest_multiple_of_ten/1","doc":"iex> ExGtin.Validation.subtract_from_nearest_multiple_of_ten(57)\n    3","ref":"ExGtin.Validation.html#subtract_from_nearest_multiple_of_ten/1-examples"},{"type":"extras","title":"ExGtin","doc":"# ExGtin\n\n![CI Status](https://github.com/kickinespresso/ex_gtin/actions/workflows/elixir.yml/badge.svg)\n[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/kickinespresso/ex_gtin/issues)\n[![Hex.pm](https://img.shields.io/hexpm/v/plug.svg)](https://www.hex.pm/packages/ex_gtin)\n[![Packagist](https://img.shields.io/packagist/l/doctrine/orm.svg)](LICENSE.md)\n\nA [GTIN](https://www.gtin.info/) (Global Trade Item Number) & UPC (Universal Price Code) Generation and Validation Library in Elixir under the GS1 specification.\n\n- GTIN-8 (EAN/UCC-8): this is an 8-digit number used predominately outside of North America\n- GTIN-12 (UPC-A): this is a 12-digit number used primarily in North America\n- GTIN-13 (EAN/UCC-13): this is a 13-digit number used predominately outside of North America - Global Location Number (GLN)\n- GTIN-14 (EAN/UCC-14 or ITF-14): this is a 14-digit number used to identify trade items at various packaging levels","ref":"readme.html"},{"type":"extras","title":"Features - ExGtin","doc":"- Supports GTIN-8, GTIN-12 (UPC-12), GTIN-13 (GLN), GTIN-14\n- Generate GTIN\n- Check GTIN validity\n- Lookup GS1 country prefix\n- Convert (normalize) GTIN-13 to GTIN-14\n\nFeatures to Come:\n\n- Global Shipment Identification Number (GSIN)\n- Serial Shipping Container Code (SSCC)","ref":"readme.html#features"},{"type":"extras","title":"Installation - ExGtin","doc":"_WARNING `1.0.1` contains breaking changes from `1.0.0`_ (I know this is a patch release but the breaking changes related to the deprecation of `check_gtin` and `generate_gtin` were noted in the changelog and docs over a year ago)\n_WARNING `1.0.0` contains breaking changes from `0.4.0`_\n\nAdd `:ex_gtin` as a dependency to your project's `mix.exs`:\n\n```elixir\ndef deps do\n  [{:ex_gtin, \"~> 1.2.0\"}]\nend\n```\n\nand run `mix deps.get` to install the `:ex_gtin` dependency\n\n```shell\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExGtin","doc":"- Check GTIN codes\n\n```elixir\niex> ExGtin.validate(\"6291041500213\")\n{:ok, \"GTIN-13\"}\n\niex> ExGtin.validate(\"6291041500214\")\n{:error, \"Invalid Code\"}\n\niex> ExGtin.validate!(\"6291041500213\")\n\"GTIN-13\"\n```\n\nPass GTIN numbers in as a String, Number or an Array\n\n```elixir\niex> number = [6, 2, 9, 1, 0, 4, 1, 5, 0, 0, 2, 1, 3]\niex> ExGtin.validate(number)\n{:ok, \"GTIN-13\"}\n\niex> number = 6_291_041_500_213\niex> ExGtin.validate(number)\n{:ok, \"GTIN-13\"}\n```\n\n- Generate GTIN codes\n\n```elixir\niex> ExGtin.generate(\"629104150021\")\n{:ok, \"6291041500213\"}\n\niex> ExGtin.generate!(\"629104150021\")\n\"6291041500213\"\n```\n\n- Lookup GS1 Prefix\n\n```elixir\niex> ExGtin.Validation.find_gs1_prefix_country(\"53523235\")\n{:ok, \"GS1 Malta\"}\n```\n\n- Convert GTIN-13 to GTIN 14\n\n```elixir\niex> ExGtin.normalize(\"6291041500213\")\n{:ok, \"16291041500210\"}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Using Strings, Arrays or Numbers - ExGtin","doc":"- String\n\n```elixir\niex> ExGtin.validate(\"6291041500213\")\n{:ok, \"GTIN-13\"}\n```\n\n- Array of Integers\n\n```elixir\niex> ExGtin.validate([6, 2, 9, 1, 0, 4, 1, 5, 0, 0, 2, 1, 3])\n{:ok, \"GTIN-13\"}\n```\n\n- Integer\n\n```elixir\niex> ExGtin.validate(6291041500213)\n{:ok, \"GTIN-13\"}\n```\n\nIntegers with leading zeros may not process properly","ref":"readme.html#using-strings-arrays-or-numbers"},{"type":"extras","title":"Reference - ExGtin","doc":"- [GTIN](https://www.gs1.org)\n- [How to calculate GTIN](https://www.gs1.org/how-calculate-check-digit-manually)\n\nDocumentation can be found at [https://hexdocs.pm/ex_gtin](https://hexdocs.pm/ex_gtin) on [HexDocs](https://hexdocs.pm).","ref":"readme.html#reference"},{"type":"extras","title":"Tests - ExGtin","doc":"Run tests with\n\n```shell\nmix test\n```\n\nRun test coverage\n\n```shell\nMIX_ENV=test mix coveralls\n```\n\nProduce Coverage report in HTML to `cover/excoveralls.html`\n\n```shell\nMIX_ENV=test mix coveralls.html\n```","ref":"readme.html#tests"},{"type":"extras","title":"Contributing - ExGtin","doc":"Please read [CONTRIBUTING.md](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.\n\nWhen making pull requests, please be sure to update the [CHANGELOG.md](CHANGELOG.md) with the corresponding changes. Please make sure that all tests pass, add tests for new functionality and that the static analysis checker `credo` is run. Use `mix pull_request_checkout.task` to ensure that everything checks out.\n\nRun static code analysis\n\n```shell\nmix credo\n```\n\nGenerate Documentation\n\n```shell\nmix docs\n```\n\nRun the gambit of tests, static analysis and coverage\n\n```shell\nmix pull_request_checkout.task\n```","ref":"readme.html#contributing"},{"type":"extras","title":"Sponsors - ExGtin","doc":"This project is sponsored by [KickinEspresso](https://kickinespresso.com/?utm_source=github&utm_medium=sponsor&utm_campaign=opensource)","ref":"readme.html#sponsors"},{"type":"extras","title":"Versioning - ExGtin","doc":"We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/kickinespresso/ex_gtin/tags).","ref":"readme.html#versioning"},{"type":"extras","title":"Code of Conduct - ExGtin","doc":"Please refer to the [Code of Conduct](CODE_OF_CONDUCT.md) for details","ref":"readme.html#code-of-conduct"},{"type":"extras","title":"Security - ExGtin","doc":"Please refer to the [Security](SECURITY.md) for details","ref":"readme.html#security"},{"type":"extras","title":"License - ExGtin","doc":"This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details","ref":"readme.html#license"},{"type":"extras","title":"Publish & Releasing - ExGtin","doc":"```shell\nmix hex.publish\n```","ref":"readme.html#publish-releasing"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}